==> cgls_cpe-0.1.21-py3-none-any.whl: cgls_cpe/processing/updateDb.py <==
# -*- coding: utf-8 -*-
""" Copernicus Global Land

Script to update the product statusid in the database
It can be called commandline to update the statusid of multiple products
can also be called from deleteFromOs in order to syn the statusid with the real availability of the product in object store

usage: update objects in DB which are removed from cdse object store
       [-h] [--startDate STARTDATE] [--endDate ENDDATE] [--sensor SENSOR]
       [--product PRODUCT] [--version VERSION] [--ancSource ANCSOURCE]
options:
  -h, --help            show this help message and exit
  --startDate STARTDATE
                        the start date
  --endDate ENDDATE     the end date
  --sensor SENSOR       the sensor abbreviation as used in waw3 bucket name
  --product PRODUCT     the product abbreviation as used in waw3 bucket name
  --version VERSION     the product version - can be empty for TOC
  --ancSource ANCSOURCE
                        the anciliary data source name as used in waw3 bucket
                        name
  --isNrt ISNRT         the product is NRT or not (only needed for BA300 products)
  
Env settings:
    environment variables are used to determine theDB to use
    
e.g.:
updateDB.py --startDate 20180625 --endDate 20180625 --sensor sen3 --product geo --version v1.2.1
updateDB.py --startDate 20190620 --endDate 20190620 --sensor anc --product activefire --version v1.2.1 --ancSource nrt
    
History
-------
========    =======  ======  ========  ========
date        version  author  jira ref  Comments
========    =======  ======  ========  ========
20250415    1.0.0    RVdG    GIOG-3605: make object storage cleanup DAG

"""
import argparse
import datetime
import os
import glob
import json

from cgls_cpe.logging import log
from cgls_cpe.config.configuration import Configuration
from cgls_cpe.common import helper
from cgls_cpe.common.helper import _str2bool
from cgls_cpe.cpl.date_time import incrDate, today, listPeriod, checkLeapYear, daysInFebruary, getNrDaysInMonth
from cgls_cpe.storage import local_storage, remote_storage
from cgls_cpe.config.model import enums
from cgls_cpe.hspf import common_helpers
from cgls_cpe.config.model.ancillary_data import AncillaryData

from cgls_cpe.config.model.enums import AncillaryDataInputCategory,AncillaryDataSourceName

from cgls_cpe.db_api import DatabaseConnection, DB_product
from cgls_cpe.config.model.enums import DB_status, DB_product_type


def getDbType(cfgDict):
    sensor    = cfgDict['sensor']
    product   = cfgDict['product'].upper()
    ancSource = cfgDict['ancSource']
    try:
        if sensor == 'anc':
            category = product
            source   = ancSource
            if category == 'activefire':
                if source == 'nrt':
                    dbProductType = DB_product_type.VIIRS_NRT.value
                else:
                    dbProductType = DB_product_type.VIIRS_NTC.value
            elif category == 'climato':
                if source == 'cams.nrt.surface.ext':
                    #TODO: check since both NRT and NTC cams data is located in the same directory
                    #dbProductType = [DB_product_type.CAMS_NRT.value, DB_product_type.CAMS_NTC.value]
                    dbProductType = None
                    print('CAMS NRT and NTC data is located in the same directory, cannot distinguish')
                if source == 'meteoconsult':
                    dbProductType = DB_product_type.METEOCONSULT.value
            else:
                dbProductType = None
        else: #sensor in ['sen3', 'meteot', 'probav']
            if product == 'GEO':
                dbProductType = DB_product_type.GEO_DAY.value
            elif product == 'PREVEBF':
                dbProductType = DB_product_type.GEO_PREVEBF.value
            elif product == 'NDVI300':
                dbProductType = DB_product_type.NDVI.value
            elif product == 'BA300':
                if cfgDict['isNrt']:
                    dbProductType = DB_product_type.BA300_NRT.value
                else:
                    dbProductType = DB_product_type.BA300_NTC.value
            elif product == 'METEOT':
                if ancSource == 'TMAX1':
                    dbProductType = DB_product_type.DMP_MAX1.value
                else:
                    dbProductType = DB_product_type.DMP_MAX10.value
            else:
                dbProductType = DB_product_type(product).value
    except:
        dbProductType = None
    return dbProductType

def process(cfgDict):
    
    version    = cfgDict['version']
    if not len(version):
        version = None
    startDate    = cfgDict['startDate']
    endDate      = cfgDict['endDate']
    
    prodDbType   = getDbType(cfgDict)
    
    if prodDbType:
        db_settings = Configuration().get_database()
        DB          = DatabaseConnection(db_settings.get_connection_string())
        
        db_startdate = datetime.datetime(int(startDate[:4]), int(startDate[4:6]), (int(startDate[6:8])))
        db_enddate   = datetime.datetime(int(endDate[:4]), int(endDate[4:6]), int(endDate[6:8]), 23, 59, 59)
        
        dbProdLst    = DB.get_products(prodDbType, status_lst=None, startdate=db_startdate, enddate=db_enddate, version=version)
        
        dbProdIdLst  = [x.id for x in dbProdLst]
        dbCommit     = False
        if len(dbProdIdLst):
            '''
            DB.update_status_by_id(dbProdIdLst, DB_status.OBSOLETE.value, 
                                   logid='products removed from waw3', close_connection=False, commit=False)
            dbCommit = True
            '''
            pass
        else:
            print('No products found for date {} - {}'.format(startDate, endDate))
        
        if dbCommit:
            DB.commit()
            print('{} products removed from waw3 are updated in DB to status {}'.format(len(dbProdIdLst, DB_status.OBSOLETE.value)))
        
        DB.close()
        #print('{} products removed from waw3 are updated in DB'.format(len(dbProdIdLst)))
    else:
        print('No product type found for settings {}'.format(cfgDict))
    return

if __name__ == '__main__':
    parser = argparse.ArgumentParser(prog='update objects in DB which are removed from cdse object store')

    parser.add_argument('--startDate', type=str, 
                        help='the start date')
    parser.add_argument('--endDate', type=str, 
                        help='the end date')
    parser.add_argument('--sensor', type=str,
                        default='sen3',
                        help='the sensor abbreviation as used in waw3 bucket name')
    parser.add_argument('--product', type=str,
                        help='the product abbreviation as used in waw3 bucket name')
    parser.add_argument('--version', type=str,
                        default='',
                        help='the product version - can be empty for TOC')
    parser.add_argument('--ancSource', type=str, default='',
                        help='the anciliary data source name as used in waw3 bucket name')
    parser.add_argument('--isNrt', type=_str2bool, default=True,
                        help='the product is NRT or not (only needed for BA300 products)')
    
    args = parser.parse_args()
    #dunder merge https://www.dynaconf.com/merging/
    os.environ['CGLS_CPE_LOGGING_CONFIG__handlers__default__level'] = 'DEBUG'
    os.environ['CGLS_CPE_LOGGING_CONFIG__loggers__cgls__level'] = 'DEBUG'
    settings   = Configuration().get_settings()
    
    process(args.__dict__)

==> cgls_cpe-0.1.23-py3-none-any.whl: cgls_cpe/processing/updateDb.py <==
# -*- coding: utf-8 -*-
""" Copernicus Global Land

Script to update the product statusid in the database
It can be called commandline to update the statusid of multiple products
can also be called from deleteFromOs in order to syn the statusid with the real availability of the product in object store

usage: update objects in DB which are removed from cdse object store
       [-h] [--startDate STARTDATE] [--endDate ENDDATE] [--sensor SENSOR]
       [--product PRODUCT] [--version VERSION] [--ancSource ANCSOURCE]
options:
  -h, --help            show this help message and exit
  --startDate STARTDATE
                        the start date
  --endDate ENDDATE     the end date
  --sensor SENSOR       the sensor abbreviation as used in waw3 bucket name
  --product PRODUCT     the product abbreviation as used in waw3 bucket name
  --version VERSION     the product version - can be empty for TOC
  --ancSource ANCSOURCE
                        the anciliary data source name as used in waw3 bucket
                        name
  --isNrt ISNRT         the product is NRT or not (only needed for BA300 products)
  
Env settings:
    environment variables are used to determine theDB to use
    
e.g.:
updateDB.py --startDate 20180625 --endDate 20180625 --sensor sen3 --product geo --version v1.2.1
updateDB.py --startDate 20190620 --endDate 20190620 --sensor anc --product activefire --version v1.2.1 --ancSource nrt
    
History
-------
========    =======  ======  ========  ========
date        version  author  jira ref  Comments
========    =======  ======  ========  ========
20250415    1.0.0    RVdG    GIOG-3605: make object storage cleanup DAG

"""
import argparse
import datetime
import os
import glob
import json

from cgls_cpe.logging import log
from cgls_cpe.config.configuration import Configuration
from cgls_cpe.common import helper
from cgls_cpe.common.helper import _str2bool
from cgls_cpe.cpl.date_time import incrDate, today, listPeriod, checkLeapYear, daysInFebruary, getNrDaysInMonth
from cgls_cpe.storage import local_storage, remote_storage
from cgls_cpe.config.model import enums
from cgls_cpe.hspf import common_helpers
from cgls_cpe.config.model.ancillary_data import AncillaryData

from cgls_cpe.config.model.enums import AncillaryDataInputCategory,AncillaryDataSourceName

from cgls_cpe.db_api import DatabaseConnection, DB_product
from cgls_cpe.config.model.enums import DB_status, DB_product_type


def getDbType(cfgDict):
    sensor    = cfgDict['sensor']
    product   = cfgDict['product'].upper()
    ancSource = cfgDict['ancSource']
    try:
        if sensor == 'anc':
            category = product
            source   = ancSource
            if category == 'activefire':
                if source == 'nrt':
                    dbProductType = DB_product_type.VIIRS_NRT.value
                else:
                    dbProductType = DB_product_type.VIIRS_NTC.value
            elif category == 'climato':
                if source == 'cams.nrt.surface.ext':
                    #TODO: check since both NRT and NTC cams data is located in the same directory
                    #dbProductType = [DB_product_type.CAMS_NRT.value, DB_product_type.CAMS_NTC.value]
                    dbProductType = None
                    print('CAMS NRT and NTC data is located in the same directory, cannot distinguish')
                if source == 'meteoconsult':
                    dbProductType = DB_product_type.METEOCONSULT.value
            else:
                dbProductType = None
        else: #sensor in ['sen3', 'meteot', 'probav']
            if product == 'GEO':
                dbProductType = DB_product_type.GEO_DAY.value
            elif product == 'PREVEBF':
                dbProductType = DB_product_type.GEO_PREVEBF.value
            elif product == 'NDVI300':
                dbProductType = DB_product_type.NDVI.value
            elif product == 'BA300':
                if cfgDict['isNrt']:
                    dbProductType = DB_product_type.BA300_NRT.value
                else:
                    dbProductType = DB_product_type.BA300_NTC.value
            elif product == 'METEOT':
                if ancSource == 'TMAX1':
                    dbProductType = DB_product_type.DMP_MAX1.value
                else:
                    dbProductType = DB_product_type.DMP_MAX10.value
            else:
                dbProductType = DB_product_type(product).value
    except:
        dbProductType = None
    return dbProductType

def process(cfgDict):
    
    version    = cfgDict['version']
    if not len(version):
        version = None
    startDate    = cfgDict['startDate']
    endDate      = cfgDict['endDate']
    
    prodDbType   = getDbType(cfgDict)
    
    if prodDbType:
        db_settings = Configuration().get_database()
        DB          = DatabaseConnection(db_settings.get_connection_string())
        
        db_startdate = datetime.datetime(int(startDate[:4]), int(startDate[4:6]), (int(startDate[6:8])))
        db_enddate   = datetime.datetime(int(endDate[:4]), int(endDate[4:6]), int(endDate[6:8]), 23, 59, 59)
        
        dbProdLst    = DB.get_products(prodDbType, status_lst=None, startdate=db_startdate, enddate=db_enddate, version=version)
        
        dbProdIdLst  = [x.id for x in dbProdLst]
        if len(dbProdIdLst):
            DB.update_status_by_id(dbProdIdLst, DB_status.CLEANUP_CANDIDATE.value, 
                                   logid='products removed from waw3', close_connection=True, commit=True)
            print('{} products removed from waw3 are updated in DB to status {}'.format(len(dbProdIdLst, DB_status.CLEANUP_CANDIDATE.value)))
        else:
            print('No products found for date {} - {}'.format(startDate, endDate))
        
    else:
        print('No product type found for settings {}'.format(cfgDict))
    return

if __name__ == '__main__':
    parser = argparse.ArgumentParser(prog='update objects in DB which are removed from cdse object store')

    parser.add_argument('--startDate', type=str, 
                        help='the start date')
    parser.add_argument('--endDate', type=str, 
                        help='the end date')
    parser.add_argument('--sensor', type=str,
                        default='sen3',
                        help='the sensor abbreviation as used in waw3 bucket name')
    parser.add_argument('--product', type=str,
                        help='the product abbreviation as used in waw3 bucket name')
    parser.add_argument('--version', type=str,
                        default='',
                        help='the product version - can be empty for TOC')
    parser.add_argument('--ancSource', type=str, default='',
                        help='the anciliary data source name as used in waw3 bucket name')
    parser.add_argument('--isNrt', type=_str2bool, default=True,
                        help='the product is NRT or not (only needed for BA300 products)')
    
    args = parser.parse_args()
    #dunder merge https://www.dynaconf.com/merging/
    os.environ['CGLS_CPE_LOGGING_CONFIG__handlers__default__level'] = 'DEBUG'
    os.environ['CGLS_CPE_LOGGING_CONFIG__loggers__cgls__level'] = 'DEBUG'
    settings   = Configuration().get_settings()
    
    process(args.__dict__)
